# live_calc
A live updating python calculator with numpy and units!
New repository for: https://github.com/LegoYoda112/py-calc

# Install
`pip install live_calc`

# Instructions
Make a `saves` folder where you plan to use the calculator.

Run `python -m live_calc` to launch.

- `cmd/ctrl + o` - open file
- `cmd/ctrl + s` - save file